@@ -2,7 +2,7 @@
 /**
  * Turba external API interface.
  *
- * $Horde: turba/lib/api.php,v 1.120.2.32 2006/06/15 17:57:43 jan Exp $
+ * $Horde: turba/lib/api.php,v 1.120.2.37 2007/08/29 11:48:34 jan Exp $
  *
  * This file defines Turba's external API interface. Other applications can
  * interact with Turba through this API.
@@ -97,7 +97,7 @@ $_services['deleteField'] = array(
 );
 
 $_services['getField'] = array(
-    'args' => array('address' => 'string', 'field' => 'string', 'sources' => '{urn:horde}stringArray', 'strict' => 'boolean'),
+    'args' => array('address' => 'string', 'field' => 'string', 'sources' => '{urn:horde}stringArray', 'strict' => 'boolean', 'multiple' => 'boolean'),
     'type' => '{urn:horde}stringArray',
 );
 
@@ -623,14 +623,12 @@ function _turba_import($content, $contentType = 'array', $source = null)
  * @param mixed $contentType  What format should the data be in?
  *                            Either a string with one of:
  *                            <pre>
+ *                             text/vcard
  *                             text/x-vcard
- *                             text/x-vcard;version=2.1
  *                            </pre>
  *                            The first produces a vcard3.0 (rfc2426),
- *                            The second produces a vcard old 2.1 format
- *                            defined imc.org. This is a custom mime tag
- *                            and does not show up in the output.
- *
+ *                            the second produces a vcard in old 2.1 format
+ *                            defined by imc.org
  * @return string  The requested data.
  */
 function _turba_export($uid, $contentType, $source = null)
@@ -679,13 +677,14 @@ function _turba_export($uid, $contentType, $source = null)
     $version = '3.0';
     switch ($contentType) {
     case 'text/x-vcard;version=2.1':
-        $version = '2.1';
     case 'text/x-vcard':
+        $version = '2.1';
+    case 'text/vcard':
         require_once 'Horde/iCalendar.php';
 
         $export = '';
         foreach ($result->objects as $obj) {
-            $vcard = $driver->tovCard($obj);
+            $vcard = $driver->tovCard($obj, $version);
             $vcard->setAttribute('VERSION', $version);
             /* vCards are not enclosed in BEGIN:VCALENDAR..END:VCALENDAR. */
             /* Export the individual cards instead. */
@@ -960,6 +959,7 @@ function _turba_search($names = array(), $sources = array(), $fields = array())
                     $listatt = $ob->getAttributes();
                     $seeninlist = array();
                     $members = $ob->listMembers();
+                    $listName = $ob->getValue('name');
 
                     if (is_a($members, 'Turba_List')) {
                         if ($members->count() > 0) {
@@ -979,7 +979,7 @@ function _turba_search($names = array(), $sources = array(), $fields = array())
                                     }
                                 }
                             }
-                            $results[$name][] = array('name' => $listatt['name'], 'email' => implode(', ', $emails), 'id' => $listatt['__key'], 'source' => $source);
+                            $results[$name][] = array('name' => $listName, 'email' => implode(', ', $emails), 'id' => $listatt['__key'], 'source' => $source);
                         }
                     }
                 }
@@ -1228,7 +1228,7 @@ function _turba_addField($address = '', $name = '', $field = '', $value = '', $s
 }
 
 function _turba_getField($address = '', $field = '', $sources = array(),
-                         $strict = false)
+                         $strict = false, $multiple = false)
 {
     require_once dirname(__FILE__) . '/base.php';
     global $cfgSources;
@@ -1248,7 +1248,7 @@ function _turba_getField($address = '', $field = '', $sources = array(),
         $sources = array(key($cfgSources));
     }
 
-    $count = 0;
+    $result = array();
     foreach ($sources as $source) {
         if (!isset($cfgSources[$source])) {
             continue;
@@ -1266,19 +1266,22 @@ function _turba_getField($address = '', $field = '', $sources = array(),
 
         while ($ob = $list->next()) {
             if ($ob->hasValue($field)) {
-                $count++;
-                $result = $ob->getValue($field);
+                $result[] = $ob->getValue($field);
             }
         }
     }
 
-    if ($count > 1) {
-        return PEAR::raiseError(_("More than 1 entry found"), 'horde.warning', null, null, $source);
-    } elseif (!isset($result)) {
+    if (count($result) > 1) {
+        if ($multiple) {
+            return $result;
+        } else {
+            return PEAR::raiseError(_("More than 1 entry found"), 'horde.warning', null, null, $source);
+        }
+    } elseif (empty($result)) {
         return PEAR::raiseError(sprintf(_("No %s entry found for %s"), $field, $address), 'horde.warning', null, null, $source);
     }
 
-    return $result;
+    return reset($result);
 }
 
 function _turba_deleteField($address = '', $field = '', $sources = array())
